@@ -20,5 +20,7 @@ typedef enum {
     MBL_MW_MODEL_METAHEALTH,
     MBL_MW_MODEL_METATRACKER,
     MBL_MW_MODEL_METAMOTION_R,
-    MBL_MW_MODEL_METAMOTION_C
+    MBL_MW_MODEL_METAMOTION_RL,
+    MBL_MW_MODEL_METAMOTION_C,
+    MBL_MW_MODEL_METAMOTION_S
 } MblMwModel;
