@@ -5,7 +5,7 @@ enum class GyroBmi160Register : uint8_t {
     DATA_INTERRUPT_ENABLE,
     CONFIG,
     DATA = 5,
-    PACKED_DATA= 0x7
+    PACKED_GYRO_DATA = 0x7
 };
 
 enum class GyroBmi270Register : uint8_t {
@@ -13,6 +13,6 @@ enum class GyroBmi270Register : uint8_t {
     DATA_INTERRUPT_ENABLE,
     CONFIG,
     DATA = 4,
-    PACKED_DATA,
+    PACKED_GYRO_DATA = 0x5,
     OFFSET
 };
\ No newline at end of file
