@@ -22,7 +22,7 @@ char* copy_string_index(const char* src, std::uint8_t i) {
 }
 
 char* copy_string(const char* src) {
-    char* buffer = (char*)std::malloc(strlen(src));
+    char* buffer = (char*)std::malloc(strlen(src) + 1);
     strcpy(buffer, src);
     return buffer;
 }
@@ -39,4 +39,4 @@ uint8_t closest_index(const float* values, size_t len, float key) {
         return fabs(val - key);
     });
     return distance(differences.begin(), min_element(differences.begin(), differences.end()));
-}
\ No newline at end of file
+}
