@@ -1,6 +1,7 @@
 from common import TestMetaWearBase, to_string_buffer
 from ctypes import *
-from mbientlab.metawear.cbindings import *
+from cbindings import *
+#from mbientlab.metawear.cbindings import *
 import threading
 
 class TestDataProcessingChain(TestMetaWearBase):
@@ -1296,4 +1297,4 @@ class TestFuserAccounter(TestMetaWearBase):
             [0x09, 0x02, 0x09, 0x03, 0x02, 0x60, 0x11, 0x31, 0x03]
         ]
 
-        self.assertEqual(self.command_history, expected)
\ No newline at end of file
+        self.assertEqual(self.command_history, expected)
